# Contributing guide
Welcome! We are happy you are reading this, as we need developers to improve the project further.

## Ways to contribute
There are many ways to contribute to the project, including:
- New features
- Bug fixes
- Documentation
- Suggestions
- Tests

## How to contribute
Before opening an issue, please read other active issues.
Be sure to include an appropriate title and description.
All relevant information should be clearly stated.
If you wrote a patch, open a new pull request.

## Development environment
Install the development packages:
```
pipenv install --dev
```

## Code style
For Python applications, use `isort` and `black` formatters. To run static analysis, use `pyright`.
